==> mingw-w64-clang-aarch64-geographiclib-2.6-1-any.pkg.tar.zst: clangarm64/share/doc/GeographicLib/html/search/pages_e.js <==
var searchData=
[
  ['paper_20on_20transverse_20mercator_20projection_0',['Figures from paper on transverse Mercator projection',['../transversemercator.html#tmfigures',1,'']]],
  ['parameters_20for_20the_20meridian_1',['Parameters for the meridian',['../geodesic.html#meridian',1,'']]],
  ['plate_20carrée_20areas_2',['Plate carrée areas',['../rhumb.html#platecarreearea',1,'']]],
  ['possible_20values_20of_20the_20dynamical_20form_20factor_3',['Possible values of the dynamical form factor',['../normalgravity.html#normalgravj2',1,'']]],
  ['potential_4',['The normal potential',['../normalgravity.html#normalgravpot',1,'']]],
  ['precision_20arithmetic_5',['Support for high precision arithmetic',['../highprec.html',1,'']]],
  ['problem_6',['problem',['../rhumb.html#rhumbform',1,'Formulation of the rhumb line problem'],['../triaxial.html#triaxial-inverse',1,'The inverse problem']]],
  ['problems_7',['Solution of great ellipse problems',['../greatellipse.html#geformulation',1,'']]],
  ['processor_20system_8',['Geoid heights on a multi-processor system',['../gravity.html#gravityparallel',1,'']]],
  ['programs_9',['Utility programs',['../utilities.html',1,'']]],
  ['projection_10',['projection',['../jacobi.html#jacobi-implementation',1,'An implementation of the projection'],['../jacobi.html#jacobi-conformal',1,'Conformal projection'],['../transversemercator.html#tmfigures',1,'Figures from paper on transverse Mercator projection'],['../jacobi.html',1,'Jacobi&apos;s conformal projection'],['../triaxial.html#triaxial-conformal',1,'Jacobi's conformal projection'],['../jacobi.html#jacobi-properties',1,'Properties of the projection'],['../transversemercator.html#testmerc',1,'Test data for the transverse Mercator projection'],['../transversemercator.html',1,'Transverse Mercator projection']]],
  ['projection_20in_20terms_20of_20elliptic_20integrals_11',['The projection in terms of elliptic integrals',['../jacobi.html#jacobi-elliptic',1,'']]],
  ['properties_20of_20the_20projection_12',['Properties of the projection',['../jacobi.html#jacobi-properties',1,'']]]
];

==> mingw-w64-clang-aarch64-geographiclib-2.7-1-any.pkg.tar.zst: clangarm64/share/doc/GeographicLib/html/search/pages_e.js <==
var searchData=
[
  ['paper_20on_20transverse_20mercator_20projection_0',['Figures from paper on transverse Mercator projection',['../transversemercator.html#tmfigures',1,'']]],
  ['parameters_20for_20the_20meridian_1',['Parameters for the meridian',['../geodesic.html#meridian',1,'']]],
  ['plate_20carrée_20areas_2',['Plate carrée areas',['../rhumb.html#platecarreearea',1,'']]],
  ['possible_20values_20of_20the_20dynamical_20form_20factor_3',['Possible values of the dynamical form factor',['../normalgravity.html#normalgravj2',1,'']]],
  ['potential_4',['The normal potential',['../normalgravity.html#normalgravpot',1,'']]],
  ['precision_20arithmetic_5',['Support for high precision arithmetic',['../highprec.html',1,'']]],
  ['problem_6',['problem',['../rhumb.html#rhumbform',1,'Formulation of the rhumb line problem'],['../triaxial.html#triaxial-inverse',1,'The inverse problem']]],
  ['problems_7',['Solution of great ellipse problems',['../greatellipse.html#geformulation',1,'']]],
  ['processor_20system_8',['Geoid heights on a multi-processor system',['../gravity.html#gravityparallel',1,'']]],
  ['programs_9',['Utility programs',['../utilities.html',1,'']]],
  ['projection_10',['projection',['../jacobi.html#jacobi-implementation',1,'An implementation of the projection'],['../jacobi.html#jacobi-conformal',1,'Conformal projection'],['../transversemercator.html#tmfigures',1,'Figures from paper on transverse Mercator projection'],['../jacobi.html',1,'Jacobi&apos;s conformal projection'],['../triaxial.html#triaxial-conformal',1,'Jacobi&apos;s conformal projection'],['../jacobi.html#jacobi-properties',1,'Properties of the projection'],['../transversemercator.html#testmerc',1,'Test data for the transverse Mercator projection'],['../transversemercator.html',1,'Transverse Mercator projection']]],
  ['projection_20in_20terms_20of_20elliptic_20integrals_11',['The projection in terms of elliptic integrals',['../jacobi.html#jacobi-elliptic',1,'']]],
  ['properties_20of_20the_20projection_12',['Properties of the projection',['../jacobi.html#jacobi-properties',1,'']]]
];
